From: Kenichi Handa <handa@m17n.org>
To: jidanni@jidanni.org
Cc: 5387@debbugs.gnu.org
Subject: bug#5387: MS950 alias for CP950 charset
Date: Fri, 15 Jan 2010 21:57:07 +0900 [thread overview]
Message-ID: <tl77hrjr0f0.fsf@m17n.org> (raw)
In-Reply-To: <87my0fy44r.fsf@jidanni.org>
In article <87my0fy44r.fsf@jidanni.org>, jidanni@jidanni.org writes:
>>> And it turns out MS950 is an alias for CP950,
>>> Where did you get that information?
> I inferred it from my single encounter.
>>> I checked <http://www.iana.org/assignments/character-sets>
>>> and found that only MS936 is listed as an alias of GBK.
> That makes two... or 1.5.
And,
iconv: MS932, MS936, MSCP949, MSCP1361
python: ms932, ms936, ms949, ms950, ms1361
hmmm...
I've just installed the attached change to accept msXXX.
canonicalize-coding-system-name is used by
coding-system-from-name, and, at least, rmail uses it.
If you are using rmail, please try the latest code, or the
attached patch.
---
Kenichi Handa
handa@m17n.org
=== modified file 'lisp/international/mule-cmds.el'
--- lisp/international/mule-cmds.el 2010-01-13 08:35:10 +0000
+++ lisp/international/mule-cmds.el 2010-01-15 12:33:24 +0000
@@ -226,19 +226,22 @@
;; and delimiter characters. Support function of
;; coding-system-from-name.
(defun canonicalize-coding-system-name (name)
- (if (string-match "^iso[-_ ]?[0-9]" name)
- ;; "iso-8859-1" -> "8859-1", "iso-2022-jp" ->"2022-jp"
- (setq name (substring name (1- (match-end 0)))))
- (let ((idx (string-match "[-_ /]" name)))
- ;; Delete "-", "_", " ", "/" but do distinguish "16-be" and "16be".
- (while idx
- (if (and (>= idx 2)
- (eq (string-match "16-[lb]e$" name (- idx 2))
- (- idx 2)))
- (setq idx (string-match "[-_ /]" name (match-end 0)))
- (setq name (concat (substring name 0 idx) (substring name (1+ idx)))
- idx (string-match "[-_ /]" name idx))))
- name))
+ (if (string-match "^\\(ms\\|ibm\\|windows-\\)\\([0-9]+\\)$" name)
+ ;; "ms950", "ibm950", "windows-950" -> "cp950"
+ (concat "cp" (match-string 2 name))
+ (if (string-match "^iso[-_ ]?[0-9]" name)
+ ;; "iso-8859-1" -> "8859-1", "iso-2022-jp" ->"2022-jp"
+ (setq name (substring name (1- (match-end 0)))))
+ (let ((idx (string-match "[-_ /]" name)))
+ ;; Delete "-", "_", " ", "/" but do distinguish "16-be" and "16be".
+ (while idx
+ (if (and (>= idx 2)
+ (eq (string-match "16-[lb]e$" name (- idx 2))
+ (- idx 2)))
+ (setq idx (string-match "[-_ /]" name (match-end 0)))
+ (setq name (concat (substring name 0 idx) (substring name (1+ idx)))
+ idx (string-match "[-_ /]" name idx))))
+ name)))
(defun coding-system-from-name (name)
"Return a coding system whose name matches with NAME (string or symbol)."
next prev parent reply other threads:[~2010-01-15 12:57 UTC|newest]
Thread overview: 7+ messages / expand[flat|nested] mbox.gz Atom feed top
2010-01-15 11:01 bug#5387: MS950 alias for CP950 charset jidanni
2010-01-15 11:46 ` Kenichi Handa
2010-01-15 11:55 ` jidanni
2010-01-15 12:57 ` Kenichi Handa [this message]
[not found] ` <873a26j1e3.fsf@jidanni.org>
2010-01-16 12:09 ` Reiner Steib
[not found] ` <871vhqw8ss.fsf@marauder.physik.uni-ulm.de>
2010-01-18 1:14 ` Kenichi Handa
2010-01-16 1:15 ` jidanni
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
List information: https://www.gnu.org/software/emacs/
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tl77hrjr0f0.fsf@m17n.org \
--to=handa@m17n.org \
--cc=5387@debbugs.gnu.org \
--cc=jidanni@jidanni.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
Code repositories for project(s) associated with this public inbox
https://git.savannah.gnu.org/cgit/emacs.git
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).